@@ -1,5 +1,10 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE TemplateHaskell #-}
+
+#ifndef MIN_VERSION_lens
+#define MIN_VERSION_lens(x,y,z) 1
+#endif
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Text.Trifecta.Highlight
@@ -22,6 +27,9 @@ module Text.Trifecta.Highlight
   ) where
 
 import Control.Lens
+#if MIN_VERSION_lens(4,13,0) && __GLASGOW_HASKELL__ >= 710
+  hiding (Empty)
+#endif
 import Data.Foldable as F
 import Data.Int (Int64)
 import Data.List (sort)
